@@ -1,33 +1,35 @@
 package TAP::Base;
 
 use strict;
-use warnings;
-
-use base 'TAP::Object';
+use vars qw($VERSION);
 
 =head1 NAME
 
-TAP::Base - Base class that provides common functionality to L<TAP::Parser>
-and L<TAP::Harness>
+TAP::Base - Base class that provides common functionality to L<TAP::Parser> and L<TAP::Harness>
 
 =head1 VERSION
 
-Version 3.51_01
+Version 3.01
 
 =cut
 
-our $VERSION = '3.51_01';
+$VERSION = '3.01';
 
-use constant GOT_TIME_HIRES => do {
+my $GOT_TIME_HIRES;
+
+BEGIN {
     eval 'use Time::HiRes qw(time);';
-    $@ ? 0 : 1;
-};
+    $GOT_TIME_HIRES = $@ ? 0 : 1;
+}
 
 =head1 SYNOPSIS
 
     package TAP::Whatever;
 
-    use base 'TAP::Base';
+    use TAP::Base;
+    
+    use vars qw($VERSION @ISA);
+    @ISA = qw(TAP::Base);
 
     # ... later ...
     
@@ -45,8 +47,17 @@ C<TAP::Base> provides callback management.
 
 =head2 Class Methods
 
+=head3 C<new>
+
 =cut
 
+sub new {
+    my ( $class, $arg_for ) = @_;
+
+    my $self = bless {}, $class;
+    return $self->_initialize($arg_for);
+}
+
 sub _initialize {
     my ( $self, $arg_for, $ok_callback ) = @_;
 
@@ -54,8 +65,8 @@ sub _initialize {
 
     $self->{ok_callbacks} = \%ok_map;
 
-    if ( my $cb = delete $arg_for->{callbacks} ) {
-        while ( my ( $event, $callback ) = each %$cb ) {
+    if ( exists $arg_for->{callbacks} ) {
+        while ( my ( $event, $callback ) = each %{ $arg_for->{callbacks} } ) {
             $self->callback( $event, $callback );
         }
     }
@@ -105,6 +116,14 @@ sub _make_callback {
     return map { $_->(@_) } @$cb;
 }
 
+sub _croak {
+    my ( $self, $message ) = @_;
+    require Carp;
+    Carp::croak($message);
+
+    return;
+}
+
 =head3 C<get_time>
 
 Return the current time using Time::HiRes if available.
@@ -119,15 +138,6 @@ Return true if the time returned by get_time is high resolution (i.e. if Time::H
 
 =cut
 
-sub time_is_hires { return GOT_TIME_HIRES }
-
-=head3 C<get_times>
-
-Return array reference of the four-element list of CPU seconds,
-as with L<perlfunc/times>.
-
-=cut
-
-sub get_times { return [ times() ] }
+sub time_is_hires { return $GOT_TIME_HIRES }
 
 1;
