@@ -1,14 +1,15 @@
 package TAP::Formatter::Console::ParallelSession;
 
 use strict;
-use warnings;
 use File::Spec;
 use File::Path;
+use TAP::Formatter::Console::Session;
 use Carp;
 
-use base 'TAP::Formatter::Console::Session';
-
 use constant WIDTH => 72;    # Because Eric says
+use vars qw($VERSION @ISA);
+
+@ISA = qw(TAP::Formatter::Console::Session);
 
 my %shared;
 
@@ -35,22 +36,27 @@ sub _create_shared_context {
     };
 }
 
+sub _need_refresh {
+    my $self      = shift;
+    my $formatter = $self->formatter;
+    $shared{$formatter}->{need_refresh}++;
+}
+
 =head1 NAME
 
 TAP::Formatter::Console::ParallelSession - Harness output delegate for parallel console output
 
 =head1 VERSION
 
-Version 3.51_01
+Version 3.01
 
 =cut
 
-our $VERSION = '3.51_01';
+$VERSION = '3.01';
 
 =head1 DESCRIPTION
 
-This provides console orientated output formatting for L<TAP::Harness>
-when run with multiple L<TAP::Harness/jobs>.
+This provides console orientated output formatting for L<TAP::Harness::Parallel>.
 
 =head1 SYNOPSIS
 
@@ -67,48 +73,27 @@ Output test preamble
 =cut
 
 sub header {
+    my $self = shift;
+    $self->_need_refresh;
 }
 
-sub _clear_ruler {
+sub _refresh {
+}
+
+sub _clear_line {
     my $self = shift;
     $self->formatter->_output( "\r" . ( ' ' x WIDTH ) . "\r" );
 }
 
-my $now = 0;
-my $start;
-
-my $trailer     = '... )===';
-my $chop_length = WIDTH - length $trailer;
-
 sub _output_ruler {
-    my ( $self, $refresh ) = @_;
-    my $new_now = time;
-    return if $new_now == $now and !$refresh;
-    $now = $new_now;
-    $start ||= $now;
+    my $self      = shift;
     my $formatter = $self->formatter;
     return if $formatter->really_quiet;
 
     my $context = $shared{$formatter};
 
-    my $ruler = sprintf '===( %7d;%d  ', $context->{tests}, $now - $start;
-
-    for my $active ( @{ $context->{active} } ) {
-        my $parser  = $active->parser;
-        my $tests   = $parser->tests_run;
-        my $planned = $parser->tests_planned || '?';
-
-        $ruler .= sprintf '%' . length($planned) . "d/$planned  ", $tests;
-    }
-    chop $ruler;    # Remove a trailing space
-    $ruler .= ')===';
-
-    if ( length $ruler > WIDTH ) {
-        $ruler =~ s/(.{$chop_length}).*/$1$trailer/o;
-    }
-    else {
-        $ruler .= '=' x ( WIDTH - length($ruler) );
-    }
+    my $ruler = sprintf( "===( %7d )", $context->{tests} );
+    $ruler .= ( '=' x ( WIDTH - length $ruler ) );
     $formatter->_output("\r$ruler");
 }
 
@@ -120,46 +105,33 @@ sub _output_ruler {
 
 sub result {
     my ( $self, $result ) = @_;
+    my $parser    = $self->parser;
     my $formatter = $self->formatter;
+    my $context   = $shared{$formatter};
+
+    $self->_refresh;
 
     # my $really_quiet = $formatter->really_quiet;
     # my $show_count   = $self->_should_show_count;
+    my $planned = $parser->tests_planned;
 
-    if ( $result->is_test ) {
-        my $context = $shared{$formatter};
-        $context->{tests}++;
-
-        my $active = $context->{active};
-        if ( @$active == 1 ) {
-
-            # There is only one test, so use the serial output format.
-            return $self->SUPER::result($result);
-        }
-
-        $self->_output_ruler( $self->parser->tests_run == 1 );
-    }
-    elsif ( $result->is_bailout ) {
+    if ( $result->is_bailout ) {
         $formatter->_failure_output(
                 "Bailout called.  Further testing stopped:  "
               . $result->explanation
               . "\n" );
     }
-}
 
-=head3 C<clear_for_close>
+    if ( $result->is_test ) {
+        $context->{tests}++;
 
-=cut
+        my $test_print_modulus = 1;
+        my $ceiling            = $context->{tests} / 5;
+        $test_print_modulus *= 2 while $test_print_modulus < $ceiling;
 
-sub clear_for_close {
-    my $self      = shift;
-    my $formatter = $self->formatter;
-    return if $formatter->really_quiet;
-    my $context = $shared{$formatter};
-    if ( @{ $context->{active} } == 1 ) {
-        $self->SUPER::clear_for_close;
-    }
-    else {
-        $self->_clear_ruler;
+        unless ( $context->{tests} % $test_print_modulus ) {
+            $self->_output_ruler;
+        }
     }
 }
 
@@ -174,8 +146,27 @@ sub close_test {
     my $formatter = $self->formatter;
     my $context   = $shared{$formatter};
 
-    $self->SUPER::close_test;
+    unless ( $formatter->really_quiet ) {
+        $self->_clear_line;
 
+        # my $output = $self->_output_method;
+        $formatter->_output(
+            $formatter->_format_name( $self->name ),
+            ' '
+        );
+    }
+
+    if ( $parser->has_problems ) {
+        $self->_output_test_failure($parser);
+    }
+    else {
+        $formatter->_output("ok\n")
+          unless $formatter->really_quiet;
+    }
+
+    $self->_output_ruler;
+
+    # $self->SUPER::close_test;
     my $active = $context->{active};
 
     my @pos = grep { $active->[$_]->name eq $name } 0 .. $#$active;
@@ -183,15 +174,9 @@ sub close_test {
     die "Can't find myself" unless @pos;
     splice @$active, $pos[0], 1;
 
-    if ( @$active > 1 ) {
-        $self->_output_ruler(1);
-    }
-    elsif ( @$active == 1 ) {
+    $self->_need_refresh;
 
-        # Print out "test/name.t ...."
-        $active->[0]->SUPER::header;
-    }
-    else {
+    unless (@$active) {
 
         # $self->formatter->_output("\n");
         delete $shared{$formatter};
