@@ -1,10 +1,8 @@
 package TAP::Parser::Aggregator;
 
 use strict;
-use warnings;
 use Benchmark;
-
-use base 'TAP::Object';
+use vars qw($VERSION);
 
 =head1 NAME
 
@@ -12,11 +10,11 @@ TAP::Parser::Aggregator - Aggregate TAP::Parser results
 
 =head1 VERSION
 
-Version 3.51_01
+Version 3.01
 
 =cut
 
-our $VERSION = '3.51_01';
+$VERSION = '3.01';
 
 =head1 SYNOPSIS
 
@@ -53,8 +51,6 @@ Returns a new C<TAP::Parser::Aggregator> object.
 
 =cut
 
-# new() implementation supplied by TAP::Object
-
 my %SUMMARY_METHOD_FOR;
 
 BEGIN {    # install summary methods
@@ -69,10 +65,9 @@ BEGIN {    # install summary methods
       wait
       exit
     );
-    $SUMMARY_METHOD_FOR{total}   = 'tests_run';
-    $SUMMARY_METHOD_FOR{planned} = 'tests_planned';
+    $SUMMARY_METHOD_FOR{total} = 'tests_run';
 
-    for my $method ( keys %SUMMARY_METHOD_FOR ) {
+    foreach my $method ( keys %SUMMARY_METHOD_FOR ) {
         next if 'total' eq $method;
         no strict 'refs';
         *$method = sub {
@@ -84,11 +79,18 @@ BEGIN {    # install summary methods
     }
 }    # end install summary methods
 
+sub new {
+    my ($class) = @_;
+    my $self = bless {}, $class;
+    $self->_initialize;
+    return $self;
+}
+
 sub _initialize {
     my ($self) = @_;
     $self->{parser_for}  = {};
     $self->{parse_order} = [];
-    for my $summary ( keys %SUMMARY_METHOD_FOR ) {
+    foreach my $summary ( keys %SUMMARY_METHOD_FOR ) {
         $self->{$summary} = 0;
         next if 'total' eq $summary;
         $self->{"descriptions_for_$summary"} = [];
@@ -122,13 +124,6 @@ sub add {
     $self->{parser_for}{$description} = $parser;
 
     while ( my ( $summary, $method ) = each %SUMMARY_METHOD_FOR ) {
-
-        # Slightly nasty. Instead we should maybe have 'cooked' accessors
-        # for results that may be masked by the parser.
-        next
-          if ( $method eq 'exit' || $method eq 'wait' )
-          && $parser->ignore_exit;
-
         if ( my $count = $parser->$method() ) {
             $self->{$summary} += $count;
             push @{ $self->{"descriptions_for_$summary"} } => $description;
@@ -173,7 +168,7 @@ sub parsers {
 sub _get_parsers {
     my ( $self, @descriptions ) = @_;
     my @parsers;
-    for my $description (@descriptions) {
+    foreach my $description (@descriptions) {
         $self->_croak("A parser for ($description) could not be found")
           unless exists $self->{parser_for}{$description};
         push @parsers => $self->{parser_for}{$description};
@@ -181,21 +176,9 @@ sub _get_parsers {
     return wantarray ? @parsers : \@parsers;
 }
 
-sub total_files {
-    my $self = shift;
-    return scalar $self->parsers;
-}
-
-sub failed_files {
-    my $self = shift;
-    my $num_bad = grep { $_->has_problems } $self->parsers;
-    return $num_bad;
-}
-
 =head3 C<descriptions>
 
-Get an array of descriptions in the order in which they were added to
-the aggregator.
+Get an array of descriptions in the order in which they were added to the aggregator.
 
 =cut
 
@@ -266,8 +249,7 @@ Return true if all the tests passed and no parse errors were detected.
 
 sub all_passed {
     my $self = shift;
-    return
-         $self->total
+    return $self->total
       && $self->total == $self->passed
       && !$self->has_errors;
 }
@@ -283,13 +265,13 @@ Depending on the outcome of the tests returns 'PASS', 'FAIL' or
 sub get_status {
     my $self = shift;
 
-    my $total  = $self->total;
-    my $passed = $self->passed;
-
-    return
-        ( $self->has_errors || $total != $passed ) ? 'FAIL'
-      : $total ? 'PASS'
-      :          'NOTESTS';
+    if ( my $total = $self->total ) {
+        return $total == $self->passed
+          && !$self->has_errors ? 'PASS' : 'FAIL';
+    }
+    else {
+        return 'NOTESTS';
+    }
 }
 
 ##############################################################################
@@ -309,8 +291,6 @@ for an explanation of description.
 
 =item * passed
 
-=item * planned
-
 =item * skipped
 
 =item * todo
@@ -380,7 +360,7 @@ Returns true if I<any> of the parsers failed.  This includes:
 
 =item * Failed tests
 
-=item * Parse errors
+=item * Parse erros
 
 =item * Bad exit or wait status
 
@@ -390,8 +370,7 @@ Returns true if I<any> of the parsers failed.  This includes:
 
 sub has_errors {
     my $self = shift;
-    return
-         $self->failed
+    return $self->failed
       || $self->parse_errors
       || $self->exit
       || $self->wait;
@@ -414,6 +393,12 @@ sub todo_failed {
     goto &todo_passed;
 }
 
+sub _croak {
+    my $proto = shift;
+    require Carp;
+    Carp::croak(@_);
+}
+
 =head1 See Also
 
 L<TAP::Parser>
