@@ -1,72 +1,52 @@
 package TAP::Parser::Grammar;
 
 use strict;
-use warnings;
+use vars qw($VERSION);
 
-use TAP::Parser::ResultFactory   ();
+use TAP::Parser::Result          ();
 use TAP::Parser::YAMLish::Reader ();
 
-use base 'TAP::Object';
-
 =head1 NAME
 
 TAP::Parser::Grammar - A grammar for the Test Anything Protocol.
 
 =head1 VERSION
 
-Version 3.51_01
+Version 3.01
 
 =cut
 
-our $VERSION = '3.51_01';
-
-=head1 SYNOPSIS
-
-  use TAP::Parser::Grammar;
-  my $grammar = $self->make_grammar({
-    iterator => $tap_parser_iterator,
-    parser   => $tap_parser,
-    version  => 12,
-  });
-
-  my $result = $grammar->tokenize;
+$VERSION = '3.01';
 
 =head1 DESCRIPTION
 
-C<TAP::Parser::Grammar> tokenizes lines from a L<TAP::Parser::Iterator> and
-constructs L<TAP::Parser::Result> subclasses to represent the tokens.
+C<TAP::Parser::Grammar> tokenizes lines from a TAP stream and constructs
+L<TAP::Parser::Result> subclasses to represent the tokens.
 
 Do not attempt to use this class directly.  It won't make sense.  It's mainly
 here to ensure that we will be able to have pluggable grammars when TAP is
 expanded at some future date (plus, this stuff was really cluttering the
 parser).
 
-=head1 METHODS
+=cut
+
+##############################################################################
 
 =head2 Class Methods
 
+
 =head3 C<new>
 
-  my $grammar = TAP::Parser::Grammar->new({
-      iterator => $iterator,
-      parser   => $parser,
-      version  => $version,
-  });
+  my $grammar = TAP::Grammar->new($stream);
 
-Returns L<TAP::Parser> grammar object that will parse the TAP stream from the
-specified iterator.  Both C<iterator> and C<parser> are required arguments.
-If C<version> is not set it defaults to C<12> (see L</set_version> for more
-details).
+Returns TAP grammar object that will parse the specified stream.
 
 =cut
 
-# new() implementation supplied by TAP::Object
-sub _initialize {
-    my ( $self, $args ) = @_;
-    $self->{iterator} = $args->{iterator};    # TODO: accessor
-    $self->{iterator} ||= $args->{stream};    # deprecated
-    $self->{parser} = $args->{parser};        # TODO: accessor
-    $self->set_version( $args->{version} || 12 );
+sub new {
+    my ( $class, $stream ) = @_;
+    my $self = bless { stream => $stream }, $class;
+    $self->set_version(12);
     return $self;
 }
 
@@ -103,10 +83,12 @@ my %language_for;
                     );
                 }
                 elsif ( 0 == $tests_planned ) {
-                    $skip = 'SKIP';
-
-                    # If we can't match # SKIP the directive should be undef.
-                    ($explanation) = $tail =~ /^#\s*SKIP\S*\s+(.*)/i;
+                    $skip        = 'SKIP';
+                    $explanation = $tail;
+                    # Trim valid SKIP directive without being strict
+                    # about its presence.
+                    $explanation =~ s/^#\s*//;
+                    $explanation =~ s/^skip\S*\s+//i;
                 }
                 elsif ( $tail !~ /^\s*$/ ) {
                     return $self->_make_unknown_token($line);
@@ -149,8 +131,8 @@ my %language_for;
                     ( $desc, $dir, $explanation ) = ( $1, $2, $3 );
                 }
                 return $self->_make_test_token(
-                    $line, $ok, $num, $desc,
-                    $dir,  $explanation
+                    $line,   $ok, $num, $desc,
+                    uc $dir, $explanation
                 );
             },
         },
@@ -163,7 +145,7 @@ my %language_for;
             },
         },
         bailout => {
-            syntax  => qr/^\s*Bail out!\s*(.*)/,
+            syntax  => qr/^Bail out!\s*(.*)/,
             handler => sub {
                 my ( $self, $line ) = @_;
                 my $explanation = $1;
@@ -178,7 +160,7 @@ my %language_for;
     my %v13 = (
         %v12,
         plan => {
-            syntax  => qr/^1\.\.(\d+)\s*(?:\s*#\s*SKIP\b(.*))?\z/i,
+            syntax  => qr/^1\.\.(\d+)(?:\s*#\s*SKIP\b(.*))?\z/i,
             handler => sub {
                 my ( $self, $line ) = @_;
                 my ( $tests_planned, $explanation ) = ( $1, $2 );
@@ -201,15 +183,6 @@ my %language_for;
                 return $self->_make_yaml_token( $pad, $marker );
             },
         },
-        pragma => {
-            syntax =>
-              qr/^ pragma \s+ ( [-+] \w+ \s* (?: , \s* [-+] \w+ \s* )* ) $/x,
-            handler => sub {
-                my ( $self, $line ) = @_;
-                my $pragmas = $1;
-                return $self->_make_pragma_token( $line, $pragmas );
-            },
-        },
     );
 
     %language_for = (
@@ -219,13 +192,7 @@ my %language_for;
         '13' => {
             tokens => \%v13,
             setup  => sub {
-                shift->{iterator}->handle_unicode;
-            },
-        },
-        '14' => {
-            tokens => \%v13,
-            setup  => sub {
-                shift->{iterator}->handle_unicode;
+                shift->{stream}->handle_unicode;
             },
         },
     );
@@ -250,8 +217,7 @@ sub set_version {
     my $version = shift;
 
     if ( my $language = $language_for{$version} ) {
-        $self->{version} = $version;
-        $self->{tokens}  = $language->{tokens};
+        $self->{tokens} = $language->{tokens};
 
         if ( my $setup = $language->{setup} ) {
             $self->$setup();
@@ -291,15 +257,13 @@ current line of TAP.
 sub tokenize {
     my $self = shift;
 
-    my $line = $self->{iterator}->next;
-    unless ( defined $line ) {
-        delete $self->{parser};    # break circular ref
-        return;
-    }
+    my $stream = $self->{stream};
+    my $line   = $stream->next;
+    return unless defined $line;
 
     my $token;
 
-    for my $token_data ( @{ $self->{ordered_tokens} } ) {
+    foreach my $token_data ( @{ $self->{ordered_tokens} } ) {
         if ( $line =~ $token_data->{syntax} ) {
             my $handler = $token_data->{handler};
             $token = $self->$handler($line);
@@ -309,7 +273,7 @@ sub tokenize {
 
     $token = $self->_make_unknown_token($line) unless $token;
 
-    return $self->{parser}->make_result($token);
+    return TAP::Parser::Result->new($token);
 }
 
 ##############################################################################
@@ -358,7 +322,7 @@ TAP parsing loop looks similar to the following:
  my @tokens;
  my $grammar = TAP::Grammar->new;
  LINE: while ( defined( my $line = $parser->_next_chunk_of_tap ) ) {
-     for my $type ( $grammar->token_types ) {
+     foreach my $type ( $grammar->token_types ) {
          my $syntax  = $grammar->syntax_for($type);
          if ( $line =~ $syntax ) {
              my $handler = $grammar->handler_for($type);
@@ -388,14 +352,10 @@ sub _make_version_token {
 sub _make_plan_token {
     my ( $self, $line, $tests_planned, $directive, $explanation, $todo ) = @_;
 
-    if (   $directive eq 'SKIP'
-        && 0 != $tests_planned
-        && $self->{version} < 13 )
-    {
+    if ( $directive eq 'SKIP' && 0 != $tests_planned ) {
         warn
           "Specified SKIP directive in plan but more than 0 tests ($line)\n";
     }
-
     return {
         type          => 'plan',
         raw           => $line,
@@ -408,18 +368,16 @@ sub _make_plan_token {
 
 sub _make_test_token {
     my ( $self, $line, $ok, $num, $desc, $dir, $explanation ) = @_;
-    return {
+    my %test = (
         ok          => $ok,
-
-        # forcing this to be an integer (and not a string) reduces memory
-        # consumption. RT #84939
-        test_num    => ( defined $num ? 0 + $num : undef ),
+        test_num    => $num,
         description => _trim($desc),
-        directive   => ( defined $dir ? uc $dir : '' ),
+        directive   => uc($dir),
         explanation => _trim($explanation),
         raw         => $line,
         type        => 'test',
-    };
+    );
+    return \%test;
 }
 
 sub _make_unknown_token {
@@ -435,7 +393,7 @@ sub _make_comment_token {
     return {
         type    => 'comment',
         raw     => $line,
-        comment => _trim($comment)
+        comment => _trim($1)
     };
 }
 
@@ -453,7 +411,7 @@ sub _make_yaml_token {
 
     my $yaml = TAP::Parser::YAMLish::Reader->new;
 
-    my $iterator = $self->{iterator};
+    my $stream = $self->{stream};
 
     # Construct a reader that reads from our input stripping leading
     # spaces from each line.
@@ -462,7 +420,7 @@ sub _make_yaml_token {
     my @extra  = ($marker);
     my $reader = sub {
         return shift @extra if @extra;
-        my $line = $iterator->next;
+        my $line = $stream->next;
         return $2 if $line =~ $strip;
         return;
     };
@@ -481,27 +439,13 @@ sub _make_yaml_token {
     };
 }
 
-sub _make_pragma_token {
-    my ( $self, $line, $pragmas ) = @_;
-    return {
-        type    => 'pragma',
-        raw     => $line,
-        pragmas => [ split /\s*,\s*/, _trim($pragmas) ],
-    };
-}
-
 sub _trim {
-    my $data = shift;
-
-    return '' unless defined $data;
-
+    my $data = shift || '';
     $data =~ s/^\s+//;
     $data =~ s/\s+$//;
     return $data;
 }
 
-1;
-
 =head1 TAP GRAMMAR
 
 B<NOTE:>  This grammar is slightly out of date.  There's still some discussion
@@ -512,7 +456,7 @@ stream-based protocol.  In fact, it's quite legal to have an infinite stream.
 For the same reason that we don't apply regexes to streams, we're not using a
 formal grammar here.  Instead, we parse the TAP in lines.
 
-For purposes for forward compatibility, any result which does not match the
+For purposes for forward compatability, any result which does not match the
 following grammar is currently referred to as
 L<TAP::Parser::Result::Unknown>.  It is I<not> a parse error.
 
@@ -573,18 +517,7 @@ A formal grammar would look similar to the following:
  positiveInteger    ::= ( digit - '0' ) {digit}
  nonNegativeInteger ::= digit {digit}
 
-=head1 SUBCLASSING
-
-Please see L<TAP::Parser/SUBCLASSING> for a subclassing overview.
-
-If you I<really> want to subclass L<TAP::Parser>'s grammar the best thing to
-do is read through the code.  There's no easy way of summarizing it here.
-
-=head1 SEE ALSO
-
-L<TAP::Object>,
-L<TAP::Parser>,
-L<TAP::Parser::Iterator>,
-L<TAP::Parser::Result>,
 
 =cut
+
+1;
