@@ -1,42 +1,42 @@
 package TAP::Parser::Iterator::Array;
 
 use strict;
-use warnings;
-
-use base 'TAP::Parser::Iterator';
+use TAP::Parser::Iterator ();
+use vars qw($VERSION @ISA);
+@ISA = 'TAP::Parser::Iterator';
 
 =head1 NAME
 
-TAP::Parser::Iterator::Array - Iterator for array-based TAP sources
+TAP::Parser::Iterator::Array - Internal TAP::Parser Iterator
 
 =head1 VERSION
 
-Version 3.51_01
+Version 3.01
 
 =cut
 
-our $VERSION = '3.51_01';
+$VERSION = '3.01';
 
 =head1 SYNOPSIS
 
   use TAP::Parser::Iterator::Array;
-  my @data = ('foo', 'bar', baz');
-  my $it   = TAP::Parser::Iterator::Array->new(\@data);
+  my $it = TAP::Parser::Iterator->new(\@array);
+
   my $line = $it->next;
 
+Originally ripped off from L<Test::Harness>.
+
 =head1 DESCRIPTION
 
-This is a simple iterator wrapper for arrays of scalar content, used by
-L<TAP::Parser>.  Unless you're writing a plugin or subclassing, you probably
-won't need to use this module directly.
+B<FOR INTERNAL USE ONLY!>
 
-=head1 METHODS
+This is a simple iterator wrapper for arrays.
 
 =head2 Class Methods
 
 =head3 C<new>
 
-Create an iterator.  Takes one argument: an C<$array_ref>
+Create an iterator.
 
 =head2 Instance Methods
 
@@ -60,15 +60,14 @@ be zero.
 
 =cut
 
-# new() implementation supplied by TAP::Object
-
-sub _initialize {
-    my ( $self, $thing ) = @_;
+sub new {
+    my ( $class, $thing ) = @_;
     chomp @$thing;
-    $self->{idx}   = 0;
-    $self->{array} = $thing;
-    $self->{exit}  = undef;
-    return $self;
+    bless {
+        idx   => 0,
+        array => $thing,
+        exit  => undef,
+    }, $class;
 }
 
 sub wait { shift->exit }
@@ -85,16 +84,3 @@ sub next_raw {
 }
 
 1;
-
-=head1 ATTRIBUTION
-
-Originally ripped off from L<Test::Harness>.
-
-=head1 SEE ALSO
-
-L<TAP::Object>,
-L<TAP::Parser>,
-L<TAP::Parser::Iterator>,
-
-=cut
-
