@@ -1,52 +1,42 @@
 package TAP::Parser::Iterator::Stream;
 
 use strict;
-use warnings;
-
-use base 'TAP::Parser::Iterator';
+use TAP::Parser::Iterator ();
+use vars qw($VERSION @ISA);
+@ISA = 'TAP::Parser::Iterator';
 
 =head1 NAME
 
-TAP::Parser::Iterator::Stream - Iterator for filehandle-based TAP sources
+TAP::Parser::Iterator::Stream - Internal TAP::Parser Iterator
 
 =head1 VERSION
 
-Version 3.51_01
+Version 3.01
 
 =cut
 
-our $VERSION = '3.51_01';
+$VERSION = '3.01';
 
 =head1 SYNOPSIS
 
-  use TAP::Parser::Iterator::Stream;
-  open( TEST, 'test.tap' );
-  my $it   = TAP::Parser::Iterator::Stream->new(\*TEST);
+  use TAP::Parser::Iterator;
+  my $it = TAP::Parser::Iterator::Stream->new(\*TEST);
+
   my $line = $it->next;
 
+Originally ripped off from L<Test::Harness>.
+
 =head1 DESCRIPTION
 
-This is a simple iterator wrapper for reading from filehandles, used by
-L<TAP::Parser>.  Unless you're writing a plugin or subclassing, you probably
-won't need to use this module directly.
+B<FOR INTERNAL USE ONLY!>
 
-=head1 METHODS
+This is a simple iterator wrapper for filehandles.
 
 =head2 Class Methods
 
 =head3 C<new>
 
-Create an iterator.  Expects one argument containing a filehandle.
-
-=cut
-
-# new() implementation supplied by TAP::Object
-
-sub _initialize {
-    my ( $self, $thing ) = @_;
-    $self->{fh} = $thing;
-    return $self;
-}
+Create an iterator.
 
 =head2 Instance Methods
 
@@ -68,6 +58,15 @@ Get the exit status for this iterator. Always returns zero.
 
 =cut
 
+sub new {
+    my ( $class, $thing ) = @_;
+    bless {
+        fh => $thing,
+    }, $class;
+}
+
+##############################################################################
+
 sub wait { shift->exit }
 sub exit { shift->{fh} ? () : 0 }
 
@@ -90,27 +89,4 @@ sub _finish {
     close delete $self->{fh};
 }
 
-sub get_select_handles {
-    my $self = shift;
-
-    # return our handle in case it's a socket or pipe (select()-able)
-    return ( $self->{fh}, )
-        if (-S $self->{fh} || -p $self->{fh});
-
-    return;
-}
-
 1;
-
-=head1 ATTRIBUTION
-
-Originally ripped off from L<Test::Harness>.
-
-=head1 SEE ALSO
-
-L<TAP::Object>,
-L<TAP::Parser>,
-L<TAP::Parser::Iterator>,
-
-=cut
-
