@@ -1,12 +1,8 @@
 package TAP::Parser::Multiplexer;
 
 use strict;
-use warnings;
-
 use IO::Select;
-use Errno;
-
-use base 'TAP::Object';
+use vars qw($VERSION);
 
 use constant IS_WIN32 => $^O =~ /^(MS)?Win32$/;
 use constant IS_VMS => $^O eq 'VMS';
@@ -18,11 +14,11 @@ TAP::Parser::Multiplexer - Multiplex multiple TAP::Parsers
 
 =head1 VERSION
 
-Version 3.51_01
+Version 3.01
 
 =cut
 
-our $VERSION = '3.51_01';
+$VERSION = '3.01';
 
 =head1 SYNOPSIS
 
@@ -55,14 +51,13 @@ Returns a new C<TAP::Parser::Multiplexer> object.
 
 =cut
 
-# new() implementation supplied by TAP::Object
-
-sub _initialize {
-    my $self = shift;
-    $self->{select} = IO::Select->new;
-    $self->{avid}   = [];                # Parsers that can't select
-    $self->{count}  = 0;
-    return $self;
+sub new {
+    my ($class) = @_;
+    return bless {
+        select => IO::Select->new,
+        avid   => [],                # Parsers that can't select
+        count  => 0,
+    }, $class;
 }
 
 ##############################################################################
@@ -131,10 +126,11 @@ sub _iter {
             return ( $parser, $stash, $result );
         }
 
-        until (@ready) {
+        unless (@ready) {
             return unless $sel->count;
+
+            # TODO: Win32 doesn't do select properly on handles...
             @ready = $sel->can_read;
-            last if @ready || !$!{EINTR};
         }
 
         my ( $h, $parser, $stash, @handles ) = @{ shift @ready };
