@@ -1,16 +1,19 @@
 package TAP::Parser::Result;
 
 use strict;
-use warnings;
+use vars qw($VERSION);
 
-use base 'TAP::Object';
+use TAP::Parser::Result::Bailout ();
+use TAP::Parser::Result::Comment ();
+use TAP::Parser::Result::Plan    ();
+use TAP::Parser::Result::Test    ();
+use TAP::Parser::Result::Unknown ();
+use TAP::Parser::Result::Version ();
+use TAP::Parser::Result::YAML    ();
 
 BEGIN {
-
-    # make is_* methods
-    my @attrs = qw( plan pragma test comment bailout version unknown yaml );
     no strict 'refs';
-    for my $token (@attrs) {
+    foreach my $token (qw( plan comment test bailout version unknown yaml )) {
         my $method = "is_$token";
         *$method = sub { return $token eq shift->type };
     }
@@ -20,62 +23,59 @@ BEGIN {
 
 =head1 NAME
 
-TAP::Parser::Result - Base class for TAP::Parser output objects
+TAP::Parser::Result - TAP::Parser output
 
 =head1 VERSION
 
-Version 3.51_01
+Version 3.01
 
 =cut
 
-our $VERSION = '3.51_01';
-
-=head1 SYNOPSIS
-
-  # abstract class - not meant to be used directly
-  # see TAP::Parser::ResultFactory for preferred usage
-
-  # directly:
-  use TAP::Parser::Result;
-  my $token  = {...};
-  my $result = TAP::Parser::Result->new( $token );
+$VERSION = '3.01';
 
 =head2 DESCRIPTION
 
-This is a simple base class used by L<TAP::Parser> to store objects that
-represent the current bit of test output data from TAP (usually a single
-line).  Unless you're subclassing, you probably won't need to use this module
-directly.
+This is merely a factory class which returns an object representing the
+current bit of test data from TAP (usually a line).  It's for internal use
+only and should not be relied upon.
+
+=cut
+
+# note that this is bad.  Makes it very difficult to subclass, but then, it
+# would be a lot of work to subclass this system.
+my %class_for = (
+    plan    => 'TAP::Parser::Result::Plan',
+    test    => 'TAP::Parser::Result::Test',
+    comment => 'TAP::Parser::Result::Comment',
+    bailout => 'TAP::Parser::Result::Bailout',
+    version => 'TAP::Parser::Result::Version',
+    unknown => 'TAP::Parser::Result::Unknown',
+    yaml    => 'TAP::Parser::Result::YAML',
+);
+
+##############################################################################
 
 =head2 METHODS
 
 =head3 C<new>
 
-  # see TAP::Parser::ResultFactory for preferred usage
-
-  # to use directly:
   my $result = TAP::Parser::Result->new($token);
 
 Returns an instance the appropriate class for the test token passed in.
 
 =cut
 
-# new() implementation provided by TAP::Object
+sub new {
+    my ( $class, $token ) = @_;
+    my $type = $token->{type};
+    return bless $token => $class_for{$type}
+      if exists $class_for{$type};
+    require Carp;
 
-sub _initialize {
-    my ( $self, $token ) = @_;
-    if ($token) {
-
-       # assign to a hash slice to make a shallow copy of the token.
-       # I guess we could assign to the hash as (by default) there are not
-       # contents, but that seems less helpful if someone wants to subclass us
-        @{$self}{ keys %$token } = values %$token;
-    }
-    return $self;
+    # this should never happen!
+    Carp::croak("Could not determine class for\n$token->{type}");
 }
 
-##############################################################################
-
 =head2 Boolean methods
 
 The following methods all return a boolean value and are to be overridden in
@@ -89,17 +89,11 @@ Indicates whether or not this is the test plan line.
 
  1..3
 
-=item * C<is_pragma>
-
-Indicates whether or not this is a pragma line.
-
- pragma +strict
-
 =item * C<is_test>
 
 Indicates whether or not this is a test line.
 
- ok 1 Is OK!
+ is $foo, $bar, $description;
 
 =item * C<is_comment>
 
@@ -212,7 +206,7 @@ Indicates whether or not the given result has a TODO or SKIP directive.
 
 sub has_directive {
     my $self = shift;
-    return ( $self->has_todo || $self->has_skip );
+    return ( $self->has_todo || $self->has_skip ) || '';
 }
 
 ##############################################################################
@@ -256,42 +250,3 @@ sub set_directive {
 }
 
 1;
-
-=head1 SUBCLASSING
-
-Please see L<TAP::Parser/SUBCLASSING> for a subclassing overview.
-
-Remember: if you want your subclass to be automatically used by the parser,
-you'll have to register it with L<TAP::Parser::ResultFactory/register_type>.
-
-If you're creating a completely new result I<type>, you'll probably need to
-subclass L<TAP::Parser::Grammar> too, or else it'll never get used.
-
-=head2 Example
-
-  package MyResult;
-
-  use strict;
-
-  use base 'TAP::Parser::Result';
-
-  # register with the factory:
-  TAP::Parser::ResultFactory->register_type( 'my_type' => __PACKAGE__ );
-
-  sub as_string { 'My results all look the same' }
-
-=head1 SEE ALSO
-
-L<TAP::Object>,
-L<TAP::Parser>,
-L<TAP::Parser::ResultFactory>,
-L<TAP::Parser::Result::Bailout>,
-L<TAP::Parser::Result::Comment>,
-L<TAP::Parser::Result::Plan>,
-L<TAP::Parser::Result::Pragma>,
-L<TAP::Parser::Result::Test>,
-L<TAP::Parser::Result::Unknown>,
-L<TAP::Parser::Result::Version>,
-L<TAP::Parser::Result::YAML>,
-
-=cut
