@@ -1,32 +1,33 @@
 package TAP::Parser::Result::Version;
 
 use strict;
-use warnings;
 
-use base 'TAP::Parser::Result';
+use vars qw($VERSION @ISA);
+use TAP::Parser::Result;
+@ISA = 'TAP::Parser::Result';
 
 =head1 NAME
 
-TAP::Parser::Result::Version - TAP syntax version token.
+TAP::Parser::Result::Version - TAP version result token.
 
 =head1 VERSION
 
-Version 3.51_01
+Version 3.01
 
 =cut
 
-our $VERSION = '3.51_01';
+$VERSION = '3.01';
 
 =head1 DESCRIPTION
 
 This is a subclass of L<TAP::Parser::Result>.  A token of this class will be
 returned if a version line is encountered.
 
- TAP version 13
+ TAP version 4
  ok 1
  not ok 2
 
-The first version of TAP to include an explicit version number is 13.
+The first version of TAP to include an explicit version number is 4.
 
 =head1 OVERRIDDEN METHODS
 
