@@ -1,35 +1,32 @@
 package TAP::Parser::YAMLish::Reader;
 
 use strict;
-use warnings;
 
-use base 'TAP::Object';
+use vars qw{$VERSION};
 
-our $VERSION = '3.51_01';
-
-                             # No EBCDIC support on early perls
-*to_native = (ord "A" == 65 || $] < 5.008)
-             ? sub { return shift }
-             : sub { utf8::unicode_to_native(shift) };
+$VERSION = '3.01';
 
 # TODO:
 #   Handle blessed object syntax
 
 # Printable characters for escapes
 my %UNESCAPES = (
-    z => "\x00", a => "\a",  t    => "\t",
-    n => "\n",   v => "\cK", f    => "\f",
-    r => "\r",   e => "\e",  '\\' => '\\',
+    z => "\x00", a => "\x07", t    => "\x09",
+    n => "\x0a", v => "\x0b", f    => "\x0c",
+    r => "\x0d", e => "\x1b", '\\' => '\\',
 );
 
 my $QQ_STRING    = qr{ " (?:\\. | [^"])* " }x;
-my $HASH_LINE    = qr{ ^ ($QQ_STRING|\S+) \s* : \s* (?: (.+?) \s* )? $ }x;
+my $HASH_LINE    = qr{ ^ ($QQ_STRING|\S+) \s* : (?: \s+ (.+?) \s* )? $ }x;
 my $IS_HASH_KEY  = qr{ ^ [\w\'\"] }x;
 my $IS_END_YAML  = qr{ ^ \.\.\. \s* $ }x;
 my $IS_QQ_STRING = qr{ ^ $QQ_STRING $ }x;
-my $IS_ARRAY_LINE = qr{ ^ - \s* ($QQ_STRING|\S+) }x;
 
-# new() implementation supplied by TAP::Object
+# Create an empty TAP::Parser::YAMLish::Reader object
+sub new {
+    my $class = shift;
+    bless {}, $class;
+}
 
 sub read {
     my $self = shift;
@@ -43,7 +40,6 @@ sub read {
 
     # Prime the reader
     $self->_next;
-    return unless $self->{next};
 
     my $doc = $self->_read;
 
@@ -62,7 +58,15 @@ sub read {
     return $doc;
 }
 
-sub get_raw { join( "\n", grep defined, @{ shift->{capture} || [] } ) . "\n" }
+sub get_raw {
+    my $self = shift;
+
+    if ( defined( my $capture = $self->{capture} ) ) {
+        return join( "\n", @$capture ) . "\n";
+    }
+
+    return '';
+}
 
 sub _peek {
     my $self = shift;
@@ -87,7 +91,7 @@ sub _read {
     my $line = $self->_peek;
 
     # Do we have a document header?
-    if ( $line =~ /^ --- (?: \s* (.+?)? \s* )? $/x ) {
+    if ( $line =~ /^ --- (?: \s* (.+?) \s* )? $/x ) {
         $self->_next;
 
         return $self->_read_scalar($1) if defined $1;    # Inline?
@@ -123,8 +127,7 @@ sub _read_qq {
 
     $str =~ s/\\"/"/gx;
     $str =~ s/ \\ ( [tartan\\favez] | x([0-9a-fA-F]{2}) ) 
-                 / (length($1) > 1) ? pack("H2", to_native($2))
-                                    : $UNESCAPES{$1} /gex;
+                 / (length($1) > 1) ? pack("H2", $2) : $UNESCAPES{$1} /gex;
     return $str;
 }
 
@@ -137,9 +140,21 @@ sub _read_scalar {
     return {} if $string eq '{}';
     return [] if $string eq '[]';
 
-    if ( $string =~ /^([>|])([+-]?)([1-9]?)$/ ) {
-        my ( $style, $chomping, $indent_base ) = ( $1, $2, $3 );
-        return $self->_read_block_scalar( $style, $chomping, $indent_base );
+    if ( $string eq '>' || $string eq '|' ) {
+
+        my ( $line, $indent ) = $self->_peek;
+        die "Multi-line scalar content missing" unless defined $line;
+
+        my @multiline = ($line);
+
+        while (1) {
+            $self->_next;
+            my ( $next, $ind ) = $self->_peek;
+            last if $ind < $indent;
+            push @multiline, $next;
+        }
+
+        return join( ( $string eq '>' ? ' ' : "\n" ), @multiline ) . "\n";
     }
 
     if ( $string =~ /^ ' (.*) ' $/x ) {
@@ -161,62 +176,6 @@ sub _read_scalar {
     return $string;
 }
 
-sub _read_block_scalar {
-    my ( $self, $style, $chomping, $indent_base ) = @_;
-
-    my ( $line, $line_indent ) = $self->_peek;
-    die "Multi-line scalar content missing" unless defined $line;
-
-    $indent_base ||= $line_indent;
-
-    my $pad = ' ' x ( $line_indent - $indent_base );
-    my @multi_lines = [ $pad, $line ];
-
-    while (1) {
-        $self->_next;
-        my ( $content, $line_indent ) = $self->_peek;
-        last if $line_indent < $indent_base;
-
-        my $pad = ' ' x ( $line_indent - $indent_base );
-        push @multi_lines, [ $pad, $content ];
-    }
-
-    my $block = '';
-    my $previous_line;
-
-    for my $current_line ( @multi_lines ) {
-        my ( $pad, $content ) = @$current_line;
-        unless ( defined $previous_line ) {
-            $block .= join( '', $pad, $content );
-            $previous_line = $current_line;
-            next;
-        }
-
-        if ( $style eq '>'
-             && length $content > 0
-             && length $pad == 0
-             && length $previous_line->[0] == 0
-             && length $previous_line->[1] > 0 )
-        {
-            $block .= ' ' . $content;
-        } else {
-            $block .= join( '', "\n", $pad, $content );
-        }
-        $previous_line = $current_line;
-    }
-
-    $block .= "\n";
-
-    if ( $chomping eq '-' ) {
-        $block =~ s/\n+$//;
-    } elsif ( $chomping eq '+' ) {
-        # noop: keep newlines
-    } else {
-         $block =~ s/\n+$/\n/;
-    }
-    return $block;
-}
-
 sub _read_nested {
     my $self = shift;
 
@@ -289,17 +248,9 @@ sub _read_hash {
         my ( $key, $value ) = ( $self->_read_scalar($1), $2 );
         $self->_next;
 
-        my ( $next_line, $next_indent ) = $self->_peek;
-
         if ( defined $value ) {
             $hash->{$key} = $self->_read_scalar($value);
         }
-        elsif (not defined $value                  # no explicit undef ("~") given
-               and $next_indent <= $limit          # next line is same or less indentation
-               and $next_line !~ $IS_ARRAY_LINE)   # arrays can start at same indent
-        {
-            $hash->{$key} = undef;
-        }
         else {
             $hash->{$key} = $self->_read_nested;
         }
@@ -326,7 +277,7 @@ TAP::Parser::YAMLish::Reader - Read YAMLish data from iterator
 
 =head1 VERSION
 
-Version 3.51_01
+Version 3.01
 
 =head1 SYNOPSIS
 
@@ -350,7 +301,7 @@ C<TAP::Parser::YAMLish::Reader> object.
 
 =head3 C<read>
 
- my $got = $reader->read($iterator);
+ my $got = $reader->read($stream);
 
 Read YAMLish from a L<TAP::Parser::Iterator> and return the data structure it
 represents.
@@ -375,9 +326,9 @@ L<http://use.perl.org/~Alias/journal/29427>
 
 =head1 COPYRIGHT
 
-Copyright 2007-2011 Andy Armstrong.
+Copyright 2007 Andy Armstrong.
 
-Portions copyright 2006-2008 Adam Kennedy.
+Portions copyright 2006-2007 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
