@@ -1,28 +1,35 @@
 package Test::Harness;
 
-use 5.006;
+require 5.00405;
 
 use strict;
-use warnings;
 
 use constant IS_WIN32 => ( $^O =~ /^(MS)?Win32$/ );
 use constant IS_VMS => ( $^O eq 'VMS' );
 
-use TAP::Harness                     ();
-use TAP::Parser::Aggregator          ();
-use TAP::Parser::Source              ();
-use TAP::Parser::SourceHandler::Perl ();
+use TAP::Harness            ();
+use TAP::Parser::Aggregator ();
 
-use Text::ParseWords qw(shellwords);
+use Exporter;
 
-use Config;
-use base 'Exporter';
+# TODO: Emulate at least some of these
+use vars qw(
+  $VERSION
+  @ISA @EXPORT @EXPORT_OK
+  $Verbose $Switches $Debug
+  $verbose $switches $debug
+  $Columns
+  $Directives
+  $Timer
+  $Strap
+  $has_time_hires
+);
 
 # $ML $Last_ML_Print
 
 BEGIN {
     eval q{use Time::HiRes 'time'};
-    our $has_time_hires = !$@;
+    $has_time_hires = !$@;
 }
 
 =head1 NAME
@@ -31,11 +38,11 @@ Test::Harness - Run Perl standard test scripts with statistics
 
 =head1 VERSION
 
-Version 3.51_01
+Version 3.01
 
 =cut
 
-our $VERSION = '3.51_01';
+$VERSION = '3.01';
 
 # Backwards compatibility for exportable variable names.
 *verbose  = *Verbose;
@@ -52,17 +59,16 @@ END {
     delete $ENV{HARNESS_VERSION};
 }
 
-our @EXPORT    = qw(&runtests);
-our @EXPORT_OK = qw(&execute_tests $verbose $switches);
+@ISA       = ('Exporter');
+@EXPORT    = qw(&runtests);
+@EXPORT_OK = qw(&execute_tests $verbose $switches);
 
-our $Verbose = $ENV{HARNESS_VERBOSE} || 0;
-our $Debug   = $ENV{HARNESS_DEBUG}   || 0;
-our $Switches = '-w';
-our $Columns = $ENV{HARNESS_COLUMNS} || $ENV{COLUMNS} || 80;
+$Verbose = $ENV{HARNESS_VERBOSE} || 0;
+$Debug   = $ENV{HARNESS_DEBUG}   || 0;
+$Switches = '-w';
+$Columns = $ENV{HARNESS_COLUMNS} || $ENV{COLUMNS} || 80;
 $Columns--;    # Some shells have trouble with a full line of text.
-our $Timer      = $ENV{HARNESS_TIMER}       || 0;
-our $Color      = $ENV{HARNESS_COLOR}       || 0;
-our $IgnoreExit = $ENV{HARNESS_IGNORE_EXIT} || 0;
+$Timer = $ENV{HARNESS_TIMER} || 0;
 
 =head1 SYNOPSIS
 
@@ -83,8 +89,7 @@ pluggable 'Straps' interface that previous versions of L<Test::Harness>
 supported is not reproduced here. Straps is now available as a stand
 alone module: L<Test::Harness::Straps>.
 
-See L<TAP::Parser>, L<TAP::Harness> for the main documentation for this
-distribution.
+See L<TAP::Parser> for the main documentation for this distribution.
 
 =head1 FUNCTIONS
 
@@ -102,42 +107,6 @@ one of the messages in the DIAGNOSTICS section.
 
 =cut
 
-sub _has_taint {
-    my $test = shift;
-    return TAP::Parser::SourceHandler::Perl->get_taint(
-        TAP::Parser::Source->shebang($test) );
-}
-
-sub _aggregate {
-    my ( $harness, $aggregate, @tests ) = @_;
-
-    # Don't propagate to our children
-    local $ENV{HARNESS_OPTIONS};
-
-    _apply_extra_INC($harness);
-    _aggregate_tests( $harness, $aggregate, @tests );
-}
-
-# Make sure the child sees all the extra junk in @INC
-sub _apply_extra_INC {
-    my $harness = shift;
-
-    $harness->callback(
-        parser_args => sub {
-            my ( $args, $test ) = @_;
-            push @{ $args->{switches} }, map {"-I$_"} _filtered_inc();
-        }
-    );
-}
-
-sub _aggregate_tests {
-    my ( $harness, $aggregate, @tests ) = @_;
-    $aggregate->start();
-    $harness->aggregate_tests( $aggregate, @tests );
-    $aggregate->stop();
-
-}
-
 sub runtests {
     my @tests = @_;
 
@@ -145,23 +114,28 @@ sub runtests {
     local ( $\, $, );
 
     my $harness   = _new_harness();
-    local $ENV{PERL_USE_UNSAFE_INC} = 1 if not exists $ENV{PERL_USE_UNSAFE_INC};
+    my $aggregate = TAP::Parser::Aggregator->new();
 
-    # Don't propagate to our children
-    local $ENV{HARNESS_OPTIONS};
-    my $aggregate = $harness->runtests(@tests);
+    $harness->aggregate_tests( $aggregate, @tests );
+
+    $harness->formatter->summary($aggregate);
 
     my $total  = $aggregate->total;
     my $passed = $aggregate->passed;
     my $failed = $aggregate->failed;
-    my $total_files = $aggregate->total_files;
-    my $failed_files = $aggregate->failed_files;
+
+    my @parsers = $aggregate->parsers;
+
+    my $num_bad = 0;
+    for my $parser (@parsers) {
+        $num_bad++ if $parser->has_problems;
+    }
 
     die(sprintf(
             "Failed %d/%d test programs. %d/%d subtests failed.\n",
-            $failed_files, $total_files, $failed, $total
+            $num_bad, scalar @parsers, $failed, $total
         )
-    ) if $failed_files;
+    ) if $num_bad;
 
     return $total && $total == $passed;
 }
@@ -185,13 +159,17 @@ sub _canon {
 }
 
 sub _new_harness {
-    my $sub_args = shift || {};
 
+    if ( defined( my $env_sw = $ENV{HARNESS_PERL_SWITCHES} ) ) {
+        $Switches .= ' ' . $env_sw if ( length($env_sw) );
+    }
+
+    # This is a bit crufty. The switches have all been joined into a
+    # single string so we have to try and recover them.
     my ( @lib, @switches );
-    my @opt = map { shellwords($_) } grep { defined } $Switches, $ENV{HARNESS_PERL_SWITCHES};
-    while ( my $opt = shift @opt ) {
+    for my $opt ( split( /\s+(?=-)/, $Switches ) ) {
         if ( $opt =~ /^ -I (.*) $ /x ) {
-            push @lib, length($1) ? $1 : shift @opt;
+            push @lib, $1;
         }
         else {
             push @switches, $opt;
@@ -200,54 +178,21 @@ sub _new_harness {
 
     push @lib, _filtered_inc();
 
-    # If $Verbose isn't numeric default to 1. This helps core.
-    my $verbosity = ( $Verbose ? ( $Verbose !~ /\d/ ) ? 1 : $Verbose : 0 );
-
     my $args = {
-        timer       => $Timer,
-        directives  => our $Directives,
-        lib         => \@lib,
-        switches    => \@switches,
-        color       => $Color,
-        verbosity   => $verbosity,
-        ignore_exit => $IgnoreExit,
+        timer      => $Timer,
+        directives => $Directives,
+        lib        => \@lib,
+        switches   => \@switches,
+        verbosity  => $Verbose,
     };
 
-    $args->{stdout} = $sub_args->{out}
-      if exists $sub_args->{out};
-
-    my $class = $ENV{HARNESS_SUBCLASS} || 'TAP::Harness';
-    if ( defined( my $env_opt = $ENV{HARNESS_OPTIONS} ) ) {
-        for my $opt ( split /:/, $env_opt ) {
-            if ( $opt =~ /^j(\d*)$/ ) {
-                $args->{jobs} = $1 || 9;
-            }
-            elsif ( $opt eq 'c' ) {
-                $args->{color} = 1;
-            }
-            elsif ( $opt =~ m/^f(.*)$/ ) {
-                my $fmt = $1;
-                $fmt =~ s/-/::/g;
-                $args->{formatter_class} = $fmt;
-            }
-            elsif ( $opt =~ m/^a(.*)$/ ) {
-                my $archive = $1;
-                $class = "TAP::Harness::Archive";
-                $args->{archive} = $archive;
-            }
-            else {
-                die "Unknown HARNESS_OPTIONS item: $opt\n";
-            }
-        }
-    }
-
-    return TAP::Harness->_construct( $class, $args );
+    return TAP::Harness->new($args);
 }
 
 # Get the parts of @INC which are changed from the stock list AND
 # preserve reordering of stock directories.
 sub _filtered_inc {
-    my @inc = grep { !ref } @INC;    #28567
+    my @inc = grep { !ref } @INC; #28567
 
     if (IS_VMS) {
 
@@ -259,7 +204,7 @@ sub _filtered_inc {
     elsif (IS_WIN32) {
 
         # Lose any trailing backslashes in the Win32 paths
-        s/[\\\/]+$// for @inc;
+        s/[\\\/+]$// foreach @inc;
     }
 
     my @default_inc = _default_inc();
@@ -289,14 +234,8 @@ sub _filtered_inc {
 
     sub _default_inc {
         return @inc if @inc;
-
-        local $ENV{PERL5LIB};
-        local $ENV{PERLLIB};
-
         my $perl = $ENV{HARNESS_PERL} || $^X;
-
-        # Avoid using -l for the benefit of Perl 6
-        chomp( @inc = `"$perl" -e "print join qq[\\n], \@INC, q[]"` );
+        chomp( @inc = `$perl -le "print join qq[\\n], \@INC"` );
         return @inc;
     }
 }
@@ -315,7 +254,9 @@ sub _check_sequence {
 sub execute_tests {
     my %args = @_;
 
-    my $harness   = _new_harness( \%args );
+    # TODO: Handle out option
+
+    my $harness   = _new_harness();
     my $aggregate = TAP::Parser::Aggregator->new();
 
     my %tot = (
@@ -348,8 +289,7 @@ sub execute_tests {
         }
     );
 
-    local $ENV{PERL_USE_UNSAFE_INC} = 1 if not exists $ENV{PERL_USE_UNSAFE_INC};
-    _aggregate( $harness, $aggregate, @{ $args{tests} } );
+    $harness->aggregate_tests( $aggregate, @{ $args{tests} } );
 
     $tot{bench} = $aggregate->elapsed;
     my @tests = $aggregate->descriptions;
@@ -498,17 +438,6 @@ This is the version of C<Test::Harness>.
 
 =over 4
 
-=item C<HARNESS_PERL_SWITCHES>
-
-Setting this adds perl command line switches to each test file run.
-
-For example, C<HARNESS_PERL_SWITCHES=-T> will turn on taint mode.
-C<HARNESS_PERL_SWITCHES=-MDevel::Cover> will run C<Devel::Cover> for
-each test.
-
-C<-w> is always set.  You can turn this off in the test with C<BEGIN {
-$^W = 0 }>.
-
 =item C<HARNESS_TIMER>
 
 Setting this to true will make the harness display the number of
@@ -521,62 +450,12 @@ If true, C<Test::Harness> will output the verbose results of running
 its tests.  Setting C<$Test::Harness::verbose> will override this,
 or you can use the C<-v> switch in the F<prove> utility.
 
-=item C<HARNESS_OPTIONS>
-
-Provide additional options to the harness. Currently supported options are:
-
-=over
-
-=item C<< j<n> >>
-
-Run <n> (default 9) parallel jobs.
-
-=item C<< c >>
-
-Try to color output. See L<TAP::Formatter::Base/"new">.
-
-=item C<< a<file.tgz> >>
-
-Will use L<TAP::Harness::Archive> as the harness class, and save the TAP to
-C<file.tgz>
-
-=item C<< fPackage-With-Dashes >>
-
-Set the formatter_class of the harness being run. Since the C<HARNESS_OPTIONS>
-is separated by C<:>, we use C<-> instead.
+If true, C<Test::Harness> will output the verbose results of running
+its tests.  Setting C<$Test::Harness::verbose> will override this,
+or you can use the C<-v> switch in the F<prove> utility.
 
 =back
 
-Multiple options may be separated by colons:
-
-    HARNESS_OPTIONS=j9:c make test
-
-=item C<HARNESS_SUBCLASS>
-
-Specifies a TAP::Harness subclass to be used in place of TAP::Harness.
-
-=item C<HARNESS_SUMMARY_COLOR_SUCCESS>
-
-Determines the L<Term::ANSIColor> for the summary in case it is successful.
-This color defaults to C<'green'>.
-
-=item C<HARNESS_SUMMARY_COLOR_FAIL>
-
-Determines the L<Term::ANSIColor> for the failure in case it is successful.
-This color defaults to C<'red'>.
-
-=back
-
-=head1 Taint Mode
-
-Normally when a Perl program is run in taint mode the contents of the
-C<PERL5LIB> environment variable do not appear in C<@INC>.
-
-Because C<PERL5LIB> is often used during testing to add build
-directories to C<@INC> C<Test::Harness> passes the names of any
-directories found in C<PERL5LIB> as -I switches. The net effect of this
-is that C<PERL5LIB> is honoured even in taint mode.
-
 =head1 SEE ALSO
 
 L<TAP::Harness>
@@ -593,8 +472,7 @@ as I make changes.
 
 Andy Armstrong  C<< <andy@hexten.net> >>
 
-L<Test::Harness> 2.64 (maintained by Andy Lester and on which this
-module is based) has this attribution:
+L<Test::Harness> (on which this module is based) has this attribution:
 
     Either Tim Bunce or Andreas Koenig, we don't know. What we know for
     sure is, that it was inspired by Larry Wall's F<TEST> script that came
@@ -604,7 +482,7 @@ module is based) has this attribution:
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2007-2011, Andy Armstrong C<< <andy@hexten.net> >>. All rights reserved.
+Copyright (c) 2007, Andy Armstrong C<< <andy@hexten.net> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
